#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['mkwikidata']

package_data = \
{'': ['*']}

install_requires = \
['requests >=2.25.1']

setup(name='mkwikidata',
      version='0.4',
      description='Utility functions for working with Wikidata',
      author='Maksym Kozlenko',
      author_email='max@kozlenko.info',
      url='http://tobeprovided',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
